@@ -29,21 +29,11 @@ def deploy(src):
     path_to_config_file = os.path.join(src, 'config.yaml')
     cfg = read(path_to_config_file, loader=yaml.load)
 
-    # Get the absolute path to the output directory and create it if it doesn't
-    # already exist.
-    path_to_dist = os.path.join(src, 'dist')
-    mkdir(path_to_dist)
-
-    # Combine the name of the Lambda function with the current timestamp to use
-    # for the output filename.
-    function_name = cfg.get('function_name')
-    output_filename = "{0}-{1}.zip".format(timestamp(), function_name)
-
     # Copy all the pip dependencies required to run your code into a temporary
     # folder then add the handler file in the root of this directory.
     # Zip the contents of this folder into a single file and output to the dist
     # directory.
-    path_to_zip_file = build(src, path_to_dist, output_filename)
+    path_to_zip_file = build(src)
 
     if function_exists(cfg, cfg.get('function_name')):
         update_function(cfg, path_to_zip_file)
@@ -51,7 +41,7 @@ def deploy(src):
         create_function(cfg, path_to_zip_file)
 
 
-def invoke(src, alt_event=None):
+def invoke(src, alt_event=None, verbose=False):
     """Simulates a call to your function.
 
     :param str src:
@@ -59,6 +49,8 @@ def invoke(src, alt_event=None):
         config.yaml and handler module (e.g.: service.py).
     :param str alt_event:
         An optional argument to override which event file to use.
+    :param bool verbose:
+        Whether to print out verbose details.
     """
     # Load and parse the config file.
     path_to_config_file = os.path.join(src, 'config.yaml')
@@ -78,15 +70,15 @@ def invoke(src, alt_event=None):
 
     # TODO: look into mocking the ``context`` variable, currently being passed
     # as None.
+
     start = time.time()
     results = fn(event, None)
     end = time.time()
-    elapsed = end - start
-    timeout = cfg.get('timeout', 15)
 
     print("{0}".format(results))
-    print("\nexecution time: {:.8f}s\nfunction execution "
-          "timeout: {:2}s".format(elapsed, timeout))
+    if verbose:
+        print("\nexecution time: {:.8f}s\nfunction execution "
+              "timeout: {:2}s".format(end - start, cfg.get('timeout', 15)))
 
 
 def init(src, minimal=False):
@@ -109,7 +101,7 @@ def init(src, minimal=False):
         copy(path_to_file, src)
 
 
-def build(src, path_to_dist, output_filename):
+def build(src):
     """Builds the file bundle.
 
     :param str path_to_handler_file:
@@ -123,6 +115,17 @@ def build(src, path_to_dist, output_filename):
     path_to_config_file = os.path.join(src, 'config.yaml')
     cfg = read(path_to_config_file, loader=yaml.load)
 
+    # Get the absolute path to the output directory and create it if it doesn't
+    # already exist.
+    dist_directory = cfg.get('dist_directory', 'dist')
+    path_to_dist = os.path.join(src, dist_directory)
+    mkdir(path_to_dist)
+
+    # Combine the name of the Lambda function with the current timestamp to use
+    # for the output filename.
+    function_name = cfg.get('function_name')
+    output_filename = "{0}-{1}.zip".format(timestamp(), function_name)
+
     path_to_temp = mkdtemp(prefix='aws-lambda')
     pip_install_to_target(path_to_temp)
 
@@ -131,18 +134,22 @@ def build(src, path_to_dist, output_filename):
                        if not output_filename.endswith('.zip')
                        else output_filename)
 
-    # Determine the filename and absolute path to the handler module.
-    handler = cfg.get('handler')
-    filename = get_handler_filename(handler)
-    path_to_handler_file = os.path.join(src, filename)
+    files = []
+    for filename in os.listdir(src):
+        if os.path.isfile(filename):
+            if filename == '.DS_Store':
+                continue
+            if filename == 'config.yaml':
+                continue
+            files.append(os.path.join(src, filename))
 
     # "cd" into `temp_path` directory.
     os.chdir(path_to_temp)
+    for f in files:
+        _, filename = os.path.split(f)
 
-    _, filename = os.path.split(path_to_handler_file)
-
-    # Copy handler file into root of the packages folder.
-    copyfile(path_to_handler_file, os.path.join(path_to_temp, filename))
+        # Copy handler file into root of the packages folder.
+        copyfile(f, os.path.join(path_to_temp, filename))
 
     # Zip them together into a single file.
     # TODO: Delete temp directory created once the archive has been compiled.
@@ -207,13 +214,14 @@ def get_account_id(aws_access_key_id, aws_secret_access_key):
     return client.get_user()['User']['Arn'].split(':')[4]
 
 
-def get_client(client, aws_access_key_id, aws_secret_access_key):
+def get_client(client, aws_access_key_id, aws_secret_access_key, region=None):
     """Shortcut for getting an initialized instance of the boto3 client."""
 
     return boto3.client(
         client,
         aws_access_key_id=aws_access_key_id,
-        aws_secret_access_key=aws_secret_access_key
+        aws_secret_access_key=aws_secret_access_key,
+        region_name=region
     )
 
 
@@ -228,7 +236,8 @@ def create_function(cfg, path_to_zip_file):
     account_id = get_account_id(aws_access_key_id, aws_secret_access_key)
     role = get_role_name(account_id)
 
-    client = get_client('lambda', aws_access_key_id, aws_secret_access_key)
+    client = get_client('lambda', aws_access_key_id, aws_secret_access_key,
+                        cfg.get('region'))
 
     client.create_function(
         FunctionName=cfg.get('function_name'),
@@ -251,7 +260,8 @@ def update_function(cfg, path_to_zip_file):
     aws_access_key_id = cfg.get('aws_access_key_id')
     aws_secret_access_key = cfg.get('aws_secret_access_key')
 
-    client = get_client('lambda', aws_access_key_id, aws_secret_access_key)
+    client = get_client('lambda', aws_access_key_id, aws_secret_access_key,
+                        cfg.get('region'))
 
     client.update_function_code(
         FunctionName=cfg.get('function_name'),
@@ -265,7 +275,8 @@ def function_exists(cfg, function_name):
 
     aws_access_key_id = cfg.get('aws_access_key_id')
     aws_secret_access_key = cfg.get('aws_secret_access_key')
-    client = get_client('lambda', aws_access_key_id, aws_secret_access_key)
+    client = get_client('lambda', aws_access_key_id, aws_secret_access_key,
+                        cfg.get('region'))
     functions = client.list_functions().get('Functions', [])
     for fn in functions:
         if fn.get('FunctionName') == function_name:
